@@ -1,3 +1,19 @@
+# tangram a general purpose table toolkit for R
+# Copyright (C) 2017 Shawn Garbett
+# 
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 #' A Node in an Abstract Syntax Tree (AST)
 #'
 #' This is the root R6 class of any term of the AST which is created
@@ -234,6 +250,7 @@ ASTPlus <- R6Class("ASTPlus",
   public  = list (
     left   = "ASTNode",
     right  = "ASTNode",
+    data   = "ASTPlus",
     initialize = function(left, right)
     {
       self$left   <- left
@@ -284,7 +301,7 @@ ASTMultiply <- R6Class("ASTMultiply",
     {
       self$left   <- left
       self$right  <- right
-      self$type   <- "Factors"
+      self$type   <- "ASTMultiply"
       self$value  <- ""
     },
     distribute = function()
